@@ -1,29 +1,13 @@
 from __future__ import unicode_literals
 
 import os
+
 from mopidy import ext, config
 from mopidy.exceptions import ExtensionError
 
 
-__doc__ = """A extension for playing music from SoundCloud.
-
-This extension handles URIs starting with ``soundcloud:`` and enables you,
-to play music from SoundCloud web service.
-
-See https://github.com/dz0ny/mopidy-soundcloud/ for further instructions on
-using this extension.
-
-**Issues:**
-
-https://github.com/dz0ny/mopidy-soundcloud/issues
-
-**Dependencies:**
-
-requests
-
-"""
-
-__version__ = '1.0.14'
+__version__ = '1.1.0'
+__url__ = 'https://github.com/mopidy/mopidy-soundcloud'
 
 
 class SoundCloudExtension(ext.Extension):
@@ -47,16 +31,11 @@ class SoundCloudExtension(ext.Extension):
         if not config.getboolean('soundcloud', 'enabled'):
             return
         if not config.get('soundcloud', 'auth_token'):
-            raise ExtensionError("In order to use SoundCloud extension you\
-             must provide auth_token, for more information referrer to \
-             https://github.com/dz0ny/mopidy-soundcloud/")
+            raise ExtensionError(
+                'In order to use SoundCloud extension you must provide an '
+                'auth token. For more information referrer to '
+                'https://github.com/mopidy/mopidy-soundcloud/')
 
-    def validate_environment(self):
-        try:
-            import requests  # noqa
-        except ImportError as e:
-            raise ExtensionError('Library requests not found', e)
-
-    def get_backend_classes(self):
+    def setup(self, registry):
         from .actor import SoundCloudBackend
-        return [SoundCloudBackend]
+        registry.add('backend', SoundCloudBackend)
