@@ -3,23 +3,21 @@ from __future__ import unicode_literals
 import logging
 import pykka
 
-from mopidy import settings
-from mopidy.backends import base
-
+from mopidy import backend
 
 from .library import SoundCloudLibraryProvider
 from .playlists import SoundCloudPlaylistsProvider
 from .soundcloud import SoundCloudClient
 
-logger = logging.getLogger('mopidy.backends.soundcloud')
+logger = logging.getLogger(__name__)
 
 
-class SoundCloudBackend(pykka.ThreadingActor, base.Backend):
+class SoundCloudBackend(pykka.ThreadingActor, backend.Backend):
 
-    def __init__(self, audio):
+    def __init__(self, config, audio):
         super(SoundCloudBackend, self).__init__()
-
-        self.sc_api = SoundCloudClient(settings.get('soundcloud', 'auth_token'))
+        self.config = config
+        self.sc_api = SoundCloudClient(config['soundcloud']['auth_token'])
         self.library = SoundCloudLibraryProvider(backend=self)
         self.playback = SoundCloudPlaybackProvider(audio=audio, backend=self)
         self.playlists = SoundCloudPlaylistsProvider(backend=self)
@@ -27,10 +25,9 @@ class SoundCloudBackend(pykka.ThreadingActor, base.Backend):
         self.uri_schemes = ['soundcloud']
 
 
-class SoundCloudPlaybackProvider(base.BasePlaybackProvider):
+class SoundCloudPlaybackProvider(backend.PlaybackProvider):
 
     def play(self, track):
-        id = track.uri.split(';')[1]
-        logger.info('Getting info for track %s with id %s' % (track.uri, id))
+        id = self.backend.sc_api.parse_track_uri(track)
         track = self.backend.sc_api.get_track(id, True)
         return super(SoundCloudPlaybackProvider, self).play(track)
