@@ -1,17 +1,12 @@
-#!/usr/local/bin/python
-# -*- coding: utf-8 -*-
-
 from __future__ import unicode_literals
-
 import logging
-import requests
 import time
-
-from requests.exceptions import RequestException
-from mopidy.models import Track, Artist, Album
 from urllib import quote_plus
 
-logger = logging.getLogger('mopidy.backends.soundcloud.client')
+import requests
+from mopidy.models import Track, Artist, Album
+
+logger = logging.getLogger(__name__)
 
 
 class cache(object):
@@ -45,11 +40,11 @@ class cache(object):
 
             except TypeError:
                 return self.func(*args)
+
         return _memoized
 
 
 class SoundCloudClient(object):
-
     CLIENT_ID = '93e33e327fd8a9b77becd179652272e2'
 
     def __init__(self, token):
@@ -57,15 +52,15 @@ class SoundCloudClient(object):
         self.http_client = requests.Session()
         self.http_client.headers.update({'Authorization': 'OAuth %s' % token})
         self.user = self.get_user()
-        logger.debug('User id for username %s is %s' % (
-            self.user.get('username'), self.user.get('id')))
-
-    @cache()
-    def get_user(self):
         try:
-            return self._get('me.json')
+            logger.debug('User id for username %s is %s' % (
+                self.user.get('username'), self.user.get('id')))
         except Exception as e:
-            logger.error('SoundCloud Authentication error: %s' % e)
+            logger.error(
+                'Authentication error: %s. Check your auth_token!' % e)
+
+    def get_user(self):
+        return self._get('me.json')
 
     # Private
 
@@ -110,13 +105,23 @@ class SoundCloudClient(object):
 
     # Public
 
-    @cache(ctl=100)
     def get_track(self, id, streamable=False):
+
         try:
             # TODO better way to handle deleted tracks
-            return self.parse_track(self._get('tracks/%s.json' % id), streamable)
+            return self.parse_track(
+                self._get('tracks/%s.json' % id), streamable)
         except Exception:
-            return
+            return Track()
+
+    def parse_track_uri(self, track):
+
+        if hasattr(track, "uri"):
+            track = track.uri
+
+        id = track.split(';')[1]
+        logger.info('Getting info for track %s with id %s' % (track, id))
+        return id
 
     @cache()
     def get_explore_category(self, category, section, pages=1):
@@ -163,28 +168,22 @@ class SoundCloudClient(object):
         url = 'https://api.soundcloud.com/%s' % url
 
         logger.debug('Requesting %s' % url)
-        req = self.http_client.get(url)
-        if req.status_code != 200:
-            raise logger.error('Request %s, failed with status code %s' % (
-                url, req.status_code))
-        try:
-            return req.json()
-        except RequestException as e:
-            logger.error('Request %s, failed with error %s' % (
-                url, e))
+        res = self.http_client.get(url)
+        res.raise_for_status()
+        return res.json()
 
     def sanitize_tracks(self, tracks):
         return filter(None, tracks)
 
     def parse_track(self, data, remote_url=False, is_search=False):
         if not data:
-            return
+            return []
         if not data['streamable']:
-            return
+            return []
         if not data['kind'] == 'track':
-            return
+            return []
         if not self.can_be_streamed(data['stream_url']):
-            return
+            return []
 
         # NOTE kwargs dict keys must be bytestrings to work on Python < 2.6.5
         # See https://github.com/mopidy/mopidy/issues/302 for details.
